--[[
BaleWrapperExtensionLoader

This script registers and loads the BaleWrapperExtension specialization for all vehicles that have the TurnLight specialization.

	@author: 	[LSFM] BayernGamers
	@date: 		11.11.2024
	@version:	1.0

	History:	v1.0 @11.11.2024 - initial implementation in FS 22
				-------------------------------------------------------------------------------------------

    License: 	This work is licensed under the Creative Commons Attribution-NoDerivs 4.0 International License (CC BY-ND 4.0).

                Terms:
                    Attribution:
                        You must give appropriate credit to the original author when using this work.
                    No Derivatives:
                        You may not alter, transform, or build upon this work in any way.
                    Usage: 
                        The work may be used for personal and commercial purposes, provided it is not modified or adapted.

                    Additional Clause:
                        This script may not be converted, adapted, or incorporated into any other game versions or platforms except by GIANTS Software.

                    Full License Text:
                        The complete license text can be found at: https://creativecommons.org/licenses/by-nd/4.0/
]]

source(Utils.getFilename("scripts/utils/LoggingUtil.lua", g_currentModDirectory))

local log = LoggingUtil

BaleWrapperExtensionLoader = {}
BaleWrapperExtensionLoader.debugLevel = 1
BaleWrapperExtensionLoader.MOD_DIRECTORY = g_currentModDirectory

if g_specializationManager:getSpecializationByName("BaleWrapperExtension") == nil then
	g_specializationManager:addSpecialization('baleWrapperExtension', 'BaleWrapperExtension', Utils.getFilename('BaleWrapperExtension.lua', BaleWrapperExtensionLoader.MOD_DIRECTORY .. "scripts/"), nil)
    log.printDevInfo("Added specialization 'baleWrapperExtension'", BaleWrapperExtensionLoader.debugLevel, true, "BaleWrapperExtensionLoader.lua")
end

for vehicleTypeName, vehicleType in pairs(g_vehicleTypeManager.types) do
    if vehicleType ~= nil and not SpecializationUtil.hasSpecialization(BaleWrapperExtension, vehicleType.specializations) and SpecializationUtil.hasSpecialization(BaleWrapper, vehicleType.specializations) then
        g_vehicleTypeManager:addSpecialization(vehicleTypeName, 'baleWrapperExtension')
        log.printInfo("Added baleWrapperExtension to " .. vehicleTypeName)
    end
end