--[[
    SetDropModeEvent

    Multiplayer event to set the drop mode of a bale wrapper.

	@author: 		[LSFM] BayernGamers
	@contributor: 	Ifko[nator]
	@date: 			11.11.2024
	@version:		1.0

	History:		v1.0 @11.11.2024 - initial implementation in FS 22
					-------------------------------------------------------------------------------------------

    License: 		This work is licensed under the Creative Commons Attribution-NoDerivs 4.0 International License (CC BY-ND 4.0).

					Terms:
						Attribution:
							You must give appropriate credit to the original author when using this work.
						No Derivatives:
							You may not alter, transform, or build upon this work in any way.
						Usage: 
							The work may be used for personal and commercial purposes, provided it is not modified or adapted.

						Additional Clause:
							This script may not be converted, adapted, or incorporated into any other game versions or platforms except by GIANTS Software.

						Full License Text:
							The complete license text can be found at: https://creativecommons.org/licenses/by-nd/4.0/
]]

SetDropModeEvent = {}
SetDropModeEvent_mt = Class(SetDropModeEvent, Event)

InitEventClass(SetDropModeEvent, "SetDropModeEvent")

function SetDropModeEvent.emptyNew()
    local self = Event.new(SetDropModeEvent_mt)

    self.className = "SetDropModeEvent"

    return self
end

function SetDropModeEvent.new(baleWrapper, currentDropModeState)
    local self = SetDropModeEvent.emptyNew()
	
    self.baleWrapper = baleWrapper
    self.currentDropModeState = currentDropModeState
    
	return self
end

function SetDropModeEvent:writeStream(streamId, connection)
    NetworkUtil.writeNodeObject(streamId, self.baleWrapper)

    streamWriteInt32(streamId, self.currentDropModeState)
end

function SetDropModeEvent:readStream(streamId, connection)
    self.baleWrapper = NetworkUtil.readNodeObject(streamId)
    self.currentDropModeState = streamReadInt32(streamId)

    self:run(connection)
end

function SetDropModeEvent:run(connection)	
	if not connection:getIsServer() then
		g_server:broadcastEvent(SetDropModeEvent.new(self.baleWrapper, self.currentDropModeState), nil, connection, self.baleWrapper)
	end
	
	if self.baleWrapper ~= nil and self.baleWrapper.setDropMode ~= nil then	
		self.baleWrapper:setDropMode(self.currentDropModeState, true)
	end
end