--[[
    ToggleBaleWrapperEvent

    Multiplayer event to toggle the bale wrapper on or off.

	@author: 		[LSFM] BayernGamers
	@contributor: 	Ifko[nator]
	@date: 			11.11.2024
	@version:		1.0

	History:		v1.0 @11.11.2024 - initial implementation in FS 22
					-------------------------------------------------------------------------------------------

    License: 		This work is licensed under the Creative Commons Attribution-NoDerivs 4.0 International License (CC BY-ND 4.0).

					Terms:
						Attribution:
							You must give appropriate credit to the original author when using this work.
						No Derivatives:
							You may not alter, transform, or build upon this work in any way.
						Usage: 
							The work may be used for personal and commercial purposes, provided it is not modified or adapted.

						Additional Clause:
							This script may not be converted, adapted, or incorporated into any other game versions or platforms except by GIANTS Software.

						Full License Text:
							The complete license text can be found at: https://creativecommons.org/licenses/by-nd/4.0/
]]

ToggleBaleWrapperEvent = {}
ToggleBaleWrapperEvent_mt = Class(ToggleBaleWrapperEvent, Event)

InitEventClass(ToggleBaleWrapperEvent, "ToggleBaleWrapperEvent")

function ToggleBaleWrapperEvent.emptyNew()
	local self = Event.new(ToggleBaleWrapperEvent_mt)
    
	return self
end

function ToggleBaleWrapperEvent.new(baleWrapper, baleWrapperIsActive)
	local self = ToggleBaleWrapperEvent.emptyNew()
	
	self.baleWrapper = baleWrapper
	self.baleWrapperIsActive = baleWrapperIsActive
	
	return self
end

function ToggleBaleWrapperEvent:readStream(streamId, connection)
	self.baleWrapper = NetworkUtil.readNodeObject(streamId)
	self.baleWrapperIsActive = streamReadBool(streamId)
    
	self:run(connection)
end

function ToggleBaleWrapperEvent:writeStream(streamId, connection)
	NetworkUtil.writeNodeObject(streamId, self.baleWrapper)

	streamWriteBool(streamId, self.baleWrapperIsActive)
end

function ToggleBaleWrapperEvent:run(connection)
	if not connection:getIsServer() then
		g_server:broadcastEvent(ToggleBaleWrapperEvent.new(self.baleWrapper, self.baleWrapperIsActive), nil, connection, self.baleWrapper)
	end
	
    if self.baleWrapper ~= nil and self.baleWrapper.toggleBaleWrapper ~= nil then
        self.baleWrapper:toggleBaleWrapper(self.baleWrapperIsActive, true)
	end
end